@@ -1,16 +1,22 @@
 # -*- coding: utf-8 -*-
 
-from cx_Freeze import setup, Executable
+"""Setup config for cx_freeze (build)
+"""
+
+
+import os.path
+
+from cx_Freeze import Executable, setup
 
 # Derive Package Paths Dynamically
-import os.path
 PYTHON_INSTALL_DIR = os.path.dirname(os.path.dirname(os.__file__))
 
-version = {}
+VERSION_DICT = {}
 with open("lbsntransform/version.py") as fp:
-    exec(fp.read(), version)
+    exec(fp.read(), VERSION_DICT)  # pylint: disable=W0122
+VERSION = VERSION_DICT['__version__']
 
-excludes_mod = ['tkinter',
+EXCLUDES_MOD = ['tkinter',
                 'matplotlib',
                 'IPython',
                 'ipykernel',
@@ -20,30 +26,32 @@ excludes_mod = ['tkinter',
                 'multiprocessing',
                 'scipy',
                 'numpy']
-packages_mod = [
-    'lbsnstructure>=0.2.6.211',
+PACKAGES_MOD = [
+    'lbsnstructure>=0.5.1',
     'protobuf',
     'psycopg2',
     'ppygis3',
     'shapely',
-    'emoji'
+    'emoji',
+    'requests',
+    'regex'
 ]
-include_folders_files = [('scripts/00_TransferAll_Default.sh')
+INCLUDE_FOLDERS_FILES = [('scripts/00_TransferAll_Default.sh')
                          ]
-build_exe_options = {'include_files': include_folders_files,
-                     "packages": packages_mod, "excludes": excludes_mod}
-base = None
-executables = [
-    Executable('lbsntransform/__main__.py', base=base,
+BUILD_EXE_OPTIONS = {'include_files': INCLUDE_FOLDERS_FILES,
+                     "packages": PACKAGES_MOD, "excludes": EXCLUDES_MOD}
+BASE = None
+EXECUTABLES = [
+    Executable('lbsntransform/__main__.py', base=BASE,
                targetName="lbsntransform.exe")
 ]
 setup(name="lbsntransform",
-      version=version['__version__'],
+      version=VERSION,
       description="Location based social network (LBSN) "
                   "data structure format & transfer tool",
       author='Alexander Dunkel',
       url='https://gitlab.vgiscience.de/lbsn/lbsntransform',
       license='GNU GPLv3 or any higher',
-      options={'build_exe': build_exe_options},
-      executables=executables,
+      options={'build_exe': BUILD_EXE_OPTIONS},
+      executables=EXECUTABLES,
       )
